<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>AlbumControl</name>
    <message>
        <location filename="../src/albumControl.cpp" line="278"/>
        <source>All photos and videos</source>
        <translation>所有照片和影片</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="306"/>
        <source>Disk is busy, cannot eject now</source>
        <translation>磁碟文件被占用，無法彈出</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="307"/>
        <source>OK</source>
        <translation>確定</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="928"/>
        <source>Fullscreen</source>
        <translation>全螢幕</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="931"/>
        <source>Exit fullscreen/slideshow</source>
        <translation>退出全螢幕/幻燈片放映</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="937"/>
        <source>Help</source>
        <translation>幫助</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="940"/>
        <source>Display shortcuts</source>
        <translation>顯示快捷鍵</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="943"/>
        <source>Display in file manager</source>
        <translation>在檔案管理器中顯示</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="946"/>
        <source>Slide show</source>
        <translation>幻燈片放映</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="949"/>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="952"/>
        <source>Export photos</source>
        <translation>匯出照片</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="955"/>
        <source>Import photos/videos</source>
        <translation>匯入照片和影片</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="958"/>
        <source>Select all</source>
        <translation>全選</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="961"/>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="964"/>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="967"/>
        <source>Photo/Video info</source>
        <translation>照片/影片訊息</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="970"/>
        <source>Set as wallpaper</source>
        <translation>設為桌布</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="973"/>
        <source>Rotate clockwise</source>
        <translation>順時針旋轉</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="976"/>
        <source>Rotate counterclockwise</source>
        <translation>逆時針旋轉</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="982"/>
        <source>Zoom in</source>
        <translation>放大照片</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="985"/>
        <source>Zoom out</source>
        <translation>縮小照片</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="988"/>
        <source>Previous</source>
        <translation>上一張</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="991"/>
        <source>Next</source>
        <translation>下一張</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="994"/>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="997"/>
        <source>Unfavorite</source>
        <translation>取消收藏</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="1000"/>
        <source>New album</source>
        <translation>建立相冊</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="1003"/>
        <source>Rename album</source>
        <translation>重新命名相冊</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="1006"/>
        <source>Page up</source>
        <translation>向上滾動一屏</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="1009"/>
        <source>Page down</source>
        <translation>向下滾動一屏</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="1051"/>
        <source>Photos</source>
        <translation>照片</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="1054"/>
        <source>Albums</source>
        <translation>相冊</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="1057"/>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="1629"/>
        <source>Favorites</source>
        <translation>我的收藏</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="1631"/>
        <source>Screen Capture</source>
        <translation>截圖錄屏</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="1633"/>
        <source>Camera</source>
        <translation>相機</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="1635"/>
        <source>Draw</source>
        <translation>畫板</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="1728"/>
        <source>Unnamed</source>
        <translation>未命名相冊</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="2173"/>
        <location filename="../src/albumControl.cpp" line="2177"/>
        <source>%1Year%2Month%3Day</source>
        <translation>%1年%2月%3日</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="2227"/>
        <source>Channel</source>
        <translation>聲道</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="2448"/>
        <source>Pictures</source>
        <translation>圖片</translation>
    </message>
</context>
<context>
    <name>AlbumTitle</name>
    <message>
        <location filename="../qml/AlbumTitle.qml" line="112"/>
        <source>New album</source>
        <translation>建立相冊</translation>
    </message>
    <message>
        <location filename="../qml/AlbumTitle.qml" line="119"/>
        <source>Import folders</source>
        <translation>從資料夾匯入</translation>
    </message>
    <message>
        <location filename="../qml/AlbumTitle.qml" line="130"/>
        <source>Album</source>
        <translation>相冊</translation>
    </message>
    <message>
        <location filename="../qml/AlbumTitle.qml" line="133"/>
        <source>Album is a stylish management tool for viewing and organizing photos and videos.</source>
        <translation>相冊是一款可多種方式瀏覽、整理照片和影片的管理工具。</translation>
    </message>
    <message>
        <location filename="../qml/AlbumTitle.qml" line="177"/>
        <source>Show side pane</source>
        <translation>展開側邊欄</translation>
    </message>
    <message>
        <location filename="../qml/AlbumTitle.qml" line="177"/>
        <source>Hide side pane</source>
        <translation>關閉側邊欄</translation>
    </message>
    <message>
        <location filename="../qml/AlbumTitle.qml" line="222"/>
        <source>Original ratio</source>
        <translation>顯示為原始比例</translation>
    </message>
    <message>
        <location filename="../qml/AlbumTitle.qml" line="222"/>
        <source>Square thumbnails</source>
        <translation>顯示為方圖</translation>
    </message>
    <message>
        <location filename="../qml/AlbumTitle.qml" line="262"/>
        <location filename="../qml/AlbumTitle.qml" line="340"/>
        <source>Y</source>
        <translation>年</translation>
    </message>
    <message>
        <location filename="../qml/AlbumTitle.qml" line="274"/>
        <location filename="../qml/AlbumTitle.qml" line="341"/>
        <source>M</source>
        <translation>月</translation>
    </message>
    <message>
        <location filename="../qml/AlbumTitle.qml" line="285"/>
        <location filename="../qml/AlbumTitle.qml" line="342"/>
        <source>D</source>
        <translation>日</translation>
    </message>
    <message>
        <location filename="../qml/AlbumTitle.qml" line="296"/>
        <location filename="../qml/AlbumTitle.qml" line="343"/>
        <source>All</source>
        <translation>所有項目</translation>
    </message>
    <message>
        <location filename="../qml/AlbumTitle.qml" line="401"/>
        <source>Search</source>
        <translation>搜尋</translation>
    </message>
    <message>
        <location filename="../qml/AlbumTitle.qml" line="483"/>
        <source>Import Photos and Videos</source>
        <translation>匯入照片和影片</translation>
    </message>
    <message>
        <location filename="../qml/AlbumTitle.qml" line="514"/>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
    <message>
        <location filename="../qml/AlbumTitle.qml" line="514"/>
        <source>Unfavorite</source>
        <translation>取消收藏</translation>
    </message>
    <message>
        <location filename="../qml/AlbumTitle.qml" line="546"/>
        <source>Rotate</source>
        <translation>旋轉</translation>
    </message>
    <message>
        <location filename="../qml/AlbumTitle.qml" line="566"/>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
</context>
<context>
    <name>AllCollection</name>
    <message>
        <location filename="../qml/ThumbnailImageView/CollecttionView/AllCollection.qml" line="73"/>
        <source>1 photo</source>
        <translation>共1張照片</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/CollecttionView/AllCollection.qml" line="75"/>
        <source>%1 photos</source>
        <translation>共%1張照片</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/CollecttionView/AllCollection.qml" line="83"/>
        <source>1 video</source>
        <translation>共1個影片</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/CollecttionView/AllCollection.qml" line="85"/>
        <source>%1 videos</source>
        <translation>共%1個影片</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/CollecttionView/AllCollection.qml" line="181"/>
        <source>No results</source>
        <translation>無結果</translation>
    </message>
</context>
<context>
    <name>CustomAlbum</name>
    <message>
        <location filename="../qml/ThumbnailImageView/CustomAlbum/CustomAlbum.qml" line="87"/>
        <source>1 photo</source>
        <translation>共1張照片</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/CustomAlbum/CustomAlbum.qml" line="89"/>
        <source>%1 photos</source>
        <translation>共%1張照片</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/CustomAlbum/CustomAlbum.qml" line="97"/>
        <source>1 video</source>
        <translation>共1個影片</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/CustomAlbum/CustomAlbum.qml" line="99"/>
        <source>%1 videos</source>
        <translation>共%1個影片</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/CustomAlbum/CustomAlbum.qml" line="155"/>
        <source>0 item</source>
        <translation>0個專案</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/CustomAlbum/CustomAlbum.qml" line="219"/>
        <source>No results</source>
        <translation>無結果</translation>
    </message>
</context>
<context>
    <name>DBManager</name>
    <message>
        <location filename="../src/dbmanager/dbmanager.cpp" line="480"/>
        <location filename="../src/dbmanager/dbmanager.cpp" line="497"/>
        <location filename="../src/dbmanager/dbmanager.cpp" line="522"/>
        <source>Screen Capture</source>
        <translation>截圖錄屏</translation>
    </message>
    <message>
        <location filename="../src/dbmanager/dbmanager.cpp" line="481"/>
        <location filename="../src/dbmanager/dbmanager.cpp" line="498"/>
        <location filename="../src/dbmanager/dbmanager.cpp" line="527"/>
        <source>Camera</source>
        <translation>相機</translation>
    </message>
    <message>
        <location filename="../src/dbmanager/dbmanager.cpp" line="482"/>
        <location filename="../src/dbmanager/dbmanager.cpp" line="532"/>
        <source>Draw</source>
        <translation>畫板</translation>
    </message>
    <message>
        <location filename="../src/dbmanager/dbmanager.cpp" line="2021"/>
        <location filename="../src/dbmanager/dbmanager.cpp" line="2041"/>
        <location filename="../src/dbmanager/dbmanager.cpp" line="2045"/>
        <location filename="../src/dbmanager/dbmanager.cpp" line="2047"/>
        <location filename="../src/dbmanager/dbmanager.cpp" line="2053"/>
        <source>(copy)</source>
        <translation>(副本)</translation>
    </message>
</context>
<context>
    <name>DayCollection</name>
    <message>
        <location filename="../qml/ThumbnailImageView/CollecttionView/DayCollection.qml" line="116"/>
        <source>Successfully added to “%1”</source>
        <translation>成功添加到“%1”</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/CollecttionView/DayCollection.qml" line="181"/>
        <source>1 photo</source>
        <translation>共1張照片</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/CollecttionView/DayCollection.qml" line="183"/>
        <source>%1 photos</source>
        <translation>共%1張照片</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/CollecttionView/DayCollection.qml" line="191"/>
        <source>1 video</source>
        <translation>共1個影片</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/CollecttionView/DayCollection.qml" line="193"/>
        <source>%1 videos</source>
        <translation>共%1個影片</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <location filename="../src/albumControl.cpp" line="1116"/>
        <source>%1 Drive</source>
        <translation>%1驅動器</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="1120"/>
        <source>Blank %1 Disc</source>
        <translation>空白%1光碟</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="1124"/>
        <source>%1 Encrypted</source>
        <translation>%1已加密</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="1127"/>
        <source>%1 Volume</source>
        <translation>%1卷</translation>
    </message>
</context>
<context>
    <name>DeleteDialog</name>
    <message>
        <location filename="../qml/Control/DeleteDialog.qml" line="48"/>
        <source>Are you sure you want to delete this file locally?</source>
        <translation>您確定要從本機刪除此文件嗎？</translation>
    </message>
    <message>
        <location filename="../qml/Control/DeleteDialog.qml" line="49"/>
        <source>You can restore it in the trash</source>
        <translation>您可以在“最近刪除”中進行復原</translation>
    </message>
    <message>
        <location filename="../qml/Control/DeleteDialog.qml" line="51"/>
        <source>Are you sure you want to delete %1 files locally?</source>
        <translation>您確定要從本機刪除這%1個文件嗎？</translation>
    </message>
    <message>
        <location filename="../qml/Control/DeleteDialog.qml" line="52"/>
        <source>You can restore them in the trash</source>
        <translation>您可以在“最近刪除”中進行復原</translation>
    </message>
    <message>
        <location filename="../qml/Control/DeleteDialog.qml" line="56"/>
        <source>Are you sure you want to permanently delete this file?</source>
        <translation>您確定要永久刪除此文件嗎？</translation>
    </message>
    <message>
        <location filename="../qml/Control/DeleteDialog.qml" line="57"/>
        <source>You cannot restore it any longer</source>
        <translation>刪除後不可復原</translation>
    </message>
    <message>
        <location filename="../qml/Control/DeleteDialog.qml" line="59"/>
        <source>Are you sure you want to permanently delete %1 files?</source>
        <translation>您確定要永久刪除這%1個文件嗎？</translation>
    </message>
    <message>
        <location filename="../qml/Control/DeleteDialog.qml" line="60"/>
        <source>You cannot restore them any longer</source>
        <translation>刪除後不可復原</translation>
    </message>
    <message>
        <location filename="../qml/Control/DeleteDialog.qml" line="111"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../qml/Control/DeleteDialog.qml" line="128"/>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
</context>
<context>
    <name>DeviceAlbum</name>
    <message>
        <location filename="../qml/ThumbnailImageView/DeviceAlbum/DeviceAlbum.qml" line="66"/>
        <source>1 photo</source>
        <translation>共1張照片</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/DeviceAlbum/DeviceAlbum.qml" line="68"/>
        <source>%1 photos</source>
        <translation>共%1張照片</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/DeviceAlbum/DeviceAlbum.qml" line="75"/>
        <source>1 video</source>
        <translation>共1個影片</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/DeviceAlbum/DeviceAlbum.qml" line="77"/>
        <source>%1 videos</source>
        <translation>共%1個影片</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/DeviceAlbum/DeviceAlbum.qml" line="179"/>
        <source>Import to:</source>
        <translation>匯入到：</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/DeviceAlbum/DeviceAlbum.qml" line="189"/>
        <location filename="../qml/ThumbnailImageView/DeviceAlbum/DeviceAlbum.qml" line="192"/>
        <source>Import</source>
        <translation>匯入</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/DeviceAlbum/DeviceAlbum.qml" line="189"/>
        <location filename="../qml/ThumbnailImageView/DeviceAlbum/DeviceAlbum.qml" line="192"/>
        <source>New Album</source>
        <translation>建立相冊</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/DeviceAlbum/DeviceAlbum.qml" line="216"/>
        <source>Import All</source>
        <translation>全部匯入</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/DeviceAlbum/DeviceAlbum.qml" line="217"/>
        <source>Import 1 Item</source>
        <translation>匯入1項</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/DeviceAlbum/DeviceAlbum.qml" line="218"/>
        <source>Import %1 Items</source>
        <translation>匯入%1項</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/DeviceAlbum/DeviceAlbum.qml" line="225"/>
        <source>Import successful</source>
        <translation>匯入成功</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/DeviceAlbum/DeviceAlbum.qml" line="276"/>
        <source>No results</source>
        <translation>無結果</translation>
    </message>
</context>
<context>
    <name>DeviceLoadDialog</name>
    <message>
        <location filename="../qml/Control/DeviceLoadDialog.qml" line="61"/>
        <source>Loading...</source>
        <translation>正在載入，請稍候...</translation>
    </message>
    <message>
        <location filename="../qml/Control/DeviceLoadDialog.qml" line="70"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../qml/Control/DeviceLoadDialog.qml" line="78"/>
        <source>Ignore</source>
        <translation>忽略</translation>
    </message>
</context>
<context>
    <name>EmptyWarningDialog</name>
    <message>
        <location filename="../qml/Control/EmptyWarningDialog.qml" line="27"/>
        <source>File name cannot be empty!</source>
        <translation>檔案名不能為空</translation>
    </message>
    <message>
        <location filename="../qml/Control/EmptyWarningDialog.qml" line="36"/>
        <source>OK</source>
        <translation>確定</translation>
    </message>
</context>
<context>
    <name>ExportDialog</name>
    <message>
        <location filename="../qml/Control/ExportDialog.qml" line="56"/>
        <source>Export</source>
        <translation>匯出</translation>
    </message>
    <message>
        <location filename="../qml/Control/ExportDialog.qml" line="73"/>
        <source>Name:</source>
        <translation>檔案名：</translation>
    </message>
    <message>
        <location filename="../qml/Control/ExportDialog.qml" line="105"/>
        <source>Save to:</source>
        <translation>儲存到：</translation>
    </message>
    <message>
        <location filename="../qml/Control/ExportDialog.qml" line="121"/>
        <source>Pictures</source>
        <translation>圖片</translation>
    </message>
    <message>
        <location filename="../qml/Control/ExportDialog.qml" line="122"/>
        <source>Documents</source>
        <translation>文件</translation>
    </message>
    <message>
        <location filename="../qml/Control/ExportDialog.qml" line="123"/>
        <source>Downloads</source>
        <translation>下載</translation>
    </message>
    <message>
        <location filename="../qml/Control/ExportDialog.qml" line="124"/>
        <source>Desktop</source>
        <translation>桌面</translation>
    </message>
    <message>
        <location filename="../qml/Control/ExportDialog.qml" line="125"/>
        <source>Videos</source>
        <translation>影片</translation>
    </message>
    <message>
        <location filename="../qml/Control/ExportDialog.qml" line="126"/>
        <source>Music</source>
        <translation>音樂</translation>
    </message>
    <message>
        <location filename="../qml/Control/ExportDialog.qml" line="127"/>
        <location filename="../qml/Control/ExportDialog.qml" line="143"/>
        <source>Select other directories</source>
        <translation>選擇其他目錄</translation>
    </message>
    <message>
        <location filename="../qml/Control/ExportDialog.qml" line="165"/>
        <source>Format:</source>
        <translation>檔案格式：</translation>
    </message>
    <message>
        <location filename="../qml/Control/ExportDialog.qml" line="203"/>
        <source>Quality:</source>
        <translation>照片質量：</translation>
    </message>
    <message>
        <location filename="../qml/Control/ExportDialog.qml" line="247"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../qml/Control/ExportDialog.qml" line="264"/>
        <source>Confirm</source>
        <translation>確定</translation>
    </message>
    <message>
        <location filename="../qml/Control/ExportDialog.qml" line="280"/>
        <source>Export successful</source>
        <translation>匯出成功</translation>
    </message>
    <message>
        <location filename="../qml/Control/ExportDialog.qml" line="282"/>
        <source>Export failed</source>
        <translation>匯出失敗</translation>
    </message>
</context>
<context>
    <name>FileControl</name>
    <message>
        <location filename="../src/filecontrol.cpp" line="838"/>
        <source>Fullscreen</source>
        <translation>全螢幕</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="842"/>
        <source>Exit fullscreen</source>
        <translation>退出全螢幕</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="846"/>
        <source>Extract text</source>
        <translation>識別文字</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="850"/>
        <source>Slide show</source>
        <translation>幻燈片放映</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="854"/>
        <source>Rename</source>
        <translation>重新命名</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="858"/>
        <location filename="../src/filecontrol.cpp" line="950"/>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="862"/>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="866"/>
        <source>Rotate clockwise</source>
        <translation>順時針旋轉</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="870"/>
        <source>Rotate counterclockwise</source>
        <translation>逆時針旋轉</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="874"/>
        <source>Set as wallpaper</source>
        <translation>設為桌布</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="878"/>
        <source>Display in file manager</source>
        <translation>在檔案管理器中顯示</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="882"/>
        <source>Image info</source>
        <translation>圖片訊息</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="886"/>
        <source>Previous</source>
        <translation>上一張</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="890"/>
        <source>Next</source>
        <translation>下一張</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="894"/>
        <source>Zoom in</source>
        <translation>放大照片</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="898"/>
        <source>Zoom out</source>
        <translation>縮小照片</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="902"/>
        <source>Open</source>
        <translation>打開</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="906"/>
        <source>Print</source>
        <translation>列印</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="930"/>
        <source>Image Viewing</source>
        <translation>查看圖片</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="934"/>
        <source>Help</source>
        <translation>幫助</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="938"/>
        <source>Display shortcuts</source>
        <translation>顯示快捷鍵</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="946"/>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="954"/>
        <source>Select all</source>
        <translation>全選</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="962"/>
        <source>Live Text</source>
        <translation>實況文字</translation>
    </message>
</context>
<context>
    <name>FilterComboBox</name>
    <message>
        <location filename="../qml/Control/FilterComboBox.qml" line="20"/>
        <source>All</source>
        <translation>所有項目</translation>
    </message>
    <message>
        <location filename="../qml/Control/FilterComboBox.qml" line="21"/>
        <source>Photos</source>
        <translation>照片</translation>
    </message>
    <message>
        <location filename="../qml/Control/FilterComboBox.qml" line="22"/>
        <source>Videos</source>
        <translation>影片</translation>
    </message>
</context>
<context>
    <name>GlobalStatus</name>
    <message>
        <location filename="../src/globalstatus.cpp" line="863"/>
        <source>1 item selected (1 photo)</source>
        <translation>已選擇1項（1張照片）</translation>
    </message>
    <message>
        <location filename="../src/globalstatus.cpp" line="865"/>
        <source>1 item selected (1 video)</source>
        <translation>已選擇1項（1個影片）</translation>
    </message>
    <message>
        <location filename="../src/globalstatus.cpp" line="867"/>
        <source>%1 items selected (%1 photos)</source>
        <translation>已選擇%1項（%1張照片）</translation>
    </message>
    <message>
        <location filename="../src/globalstatus.cpp" line="869"/>
        <source>%1 items selected (%1 videos)</source>
        <translation>已選擇%1項（%1個影片）</translation>
    </message>
    <message>
        <location filename="../src/globalstatus.cpp" line="871"/>
        <source>%1 item selected (1 photo, 1 video)</source>
        <translation>已選擇%1項（1張照片，1個影片）</translation>
    </message>
    <message>
        <location filename="../src/globalstatus.cpp" line="873"/>
        <source>%1 items selected (1 photo, %2 videos)</source>
        <translation>已選擇%1項（1張照片，%2個影片）</translation>
    </message>
    <message>
        <location filename="../src/globalstatus.cpp" line="875"/>
        <source>%1 items selected (%2 photos, 1 video)</source>
        <translation>已選擇%1項（%2張照片，1個影片）</translation>
    </message>
    <message>
        <location filename="../src/globalstatus.cpp" line="877"/>
        <source>%1 items selected (%2 photos, %3 videos)</source>
        <translation>已選擇%1項（%2張照片，%3個影片）</translation>
    </message>
</context>
<context>
    <name>GlobalVar</name>
    <message>
        <location filename="../qml/GlobalVar.qml" line="30"/>
        <source>The photo/video already exists</source>
        <translation>照片/影片已存在</translation>
    </message>
    <message>
        <location filename="../qml/GlobalVar.qml" line="38"/>
        <location filename="../qml/GlobalVar.qml" line="46"/>
        <source>The file format is not supported</source>
        <translation>該檔案格式不支援</translation>
    </message>
</context>
<context>
    <name>HaveImportedView</name>
    <message>
        <location filename="../qml/ThumbnailImageView/HaveImportedView/HaveImportedView.qml" line="98"/>
        <source>Successfully added to “%1”</source>
        <translation>成功添加到“%1”</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/HaveImportedView/HaveImportedView.qml" line="153"/>
        <source>1 photo</source>
        <translation>共1張照片</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/HaveImportedView/HaveImportedView.qml" line="155"/>
        <source>%1 photos</source>
        <translation>共%1張照片</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/HaveImportedView/HaveImportedView.qml" line="163"/>
        <source>1 video</source>
        <translation>共1個影片</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/HaveImportedView/HaveImportedView.qml" line="165"/>
        <source>%1 videos</source>
        <translation>共%1個影片</translation>
    </message>
</context>
<context>
    <name>ImportTimeLineView</name>
    <message>
        <location filename="../src/widgets/importtimelineview/importtimelineview.cpp" line="211"/>
        <location filename="../src/widgets/importtimelineview/importtimelineview.cpp" line="430"/>
        <source>Import</source>
        <translation>匯入照片</translation>
    </message>
    <message>
        <location filename="../src/widgets/importtimelineview/importtimelineview.cpp" line="341"/>
        <source>1 photo</source>
        <translation>共1張照片</translation>
    </message>
    <message>
        <location filename="../src/widgets/importtimelineview/importtimelineview.cpp" line="343"/>
        <source>1 video</source>
        <translation>共1個影片</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/widgets/importtimelineview/importtimelineview.cpp" line="345"/>
        <source>%n photos</source>
        <translation>
            <numerusform>共%n張照片</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/widgets/importtimelineview/importtimelineview.cpp" line="347"/>
        <source>%n videos</source>
        <translation>
            <numerusform>共%n個影片</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/widgets/importtimelineview/importtimelineview.cpp" line="349"/>
        <source>%n items</source>
        <translation>
            <numerusform>共%n項</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ImportedlListView</name>
    <message>
        <location filename="../qml/ThumbnailImageView/HaveImportedView/ImportedlListView.qml" line="150"/>
        <location filename="../qml/ThumbnailImageView/HaveImportedView/ImportedlListView.qml" line="423"/>
        <source>Imported on</source>
        <translation>匯入於</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/HaveImportedView/ImportedlListView.qml" line="150"/>
        <location filename="../qml/ThumbnailImageView/HaveImportedView/ImportedlListView.qml" line="423"/>
        <source>1 item</source>
        <translation>共1項</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/HaveImportedView/ImportedlListView.qml" line="150"/>
        <location filename="../qml/ThumbnailImageView/HaveImportedView/ImportedlListView.qml" line="423"/>
        <source>%1 items</source>
        <translation>共%1項</translation>
    </message>
</context>
<context>
    <name>InformationDialog</name>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="82"/>
        <source>Basic info</source>
        <translation>基本訊息</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="95"/>
        <source>File name</source>
        <translation>檔案名</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="106"/>
        <source>Size</source>
        <translation>大小</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="113"/>
        <source>Dimensions</source>
        <translation>照片尺寸</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="120"/>
        <source>Type</source>
        <translation>文件類型</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="132"/>
        <source>Date captured</source>
        <translation>拍攝日期</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="139"/>
        <source>Date modified</source>
        <translation>修改日期</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="149"/>
        <source>Details</source>
        <translation>詳細訊息</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="162"/>
        <source>Aperture</source>
        <translation>光圈大小</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="170"/>
        <source>Exposure program</source>
        <translation>曝光程式</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="177"/>
        <source>Focal length</source>
        <translation>焦距</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="183"/>
        <source>ISO</source>
        <translation>ISO感光度</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="190"/>
        <source>Exposure mode</source>
        <translation>曝光模式</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="196"/>
        <source>Exposure time</source>
        <translation>曝光時間</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="202"/>
        <source>Flash</source>
        <translation>閃光燈</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="209"/>
        <source>Flash compensation</source>
        <translation>閃光燈補償</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="215"/>
        <source>Max aperture</source>
        <translation>最大光圈值</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="222"/>
        <source>Colorspace</source>
        <translation>顏色空間</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="229"/>
        <source>Metering mode</source>
        <translation>測光模式</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="236"/>
        <source>White balance</source>
        <translation>白平衡</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="247"/>
        <source>Device model</source>
        <translation>裝置型號</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="254"/>
        <source>Lens model</source>
        <translation>鏡頭型號</translation>
    </message>
</context>
<context>
    <name>MainAlbumView</name>
    <message>
        <location filename="../qml/MainAlbumView.qml" line="245"/>
        <source>Importing...</source>
        <translation>正在匯入，請稍候…</translation>
    </message>
    <message>
        <location filename="../qml/MainAlbumView.qml" line="246"/>
        <location filename="../qml/MainAlbumView.qml" line="252"/>
        <source>Imported:</source>
        <translation>已匯入：</translation>
    </message>
    <message>
        <location filename="../qml/MainAlbumView.qml" line="253"/>
        <location filename="../qml/MainAlbumView.qml" line="290"/>
        <source>%1/%2</source>
        <translation>%1/%2</translation>
    </message>
    <message>
        <location filename="../qml/MainAlbumView.qml" line="263"/>
        <source>Import successful</source>
        <translation>匯入成功</translation>
    </message>
    <message>
        <location filename="../qml/MainAlbumView.qml" line="270"/>
        <location filename="../qml/MainAlbumView.qml" line="276"/>
        <source>Import failed</source>
        <translation>匯入失敗</translation>
    </message>
    <message>
        <location filename="../qml/MainAlbumView.qml" line="281"/>
        <source>Deleted:</source>
        <translation>已刪除：</translation>
    </message>
    <message>
        <location filename="../qml/MainAlbumView.qml" line="283"/>
        <source>Deleting...</source>
        <translation>正在刪除...</translation>
    </message>
</context>
<context>
    <name>MainStack</name>
    <message>
        <location filename="../qml/PreviewImageViewer/MainStack.qml" line="125"/>
        <source>Select pictures</source>
        <translation>選擇圖片</translation>
    </message>
</context>
<context>
    <name>MenuItemStates</name>
    <message>
        <location filename="../qml/MenuItemStates.qml" line="120"/>
        <source>Export successful</source>
        <translation>匯出成功</translation>
    </message>
    <message>
        <location filename="../qml/MenuItemStates.qml" line="122"/>
        <source>Export failed</source>
        <translation>匯出失敗</translation>
    </message>
</context>
<context>
    <name>MonthCollection</name>
    <message>
        <location filename="../qml/ThumbnailImageView/CollecttionView/MonthCollection.qml" line="154"/>
        <source>%1/%2</source>
        <translation>%1/%2</translation>
    </message>
</context>
<context>
    <name>NewAlbumDialog</name>
    <message>
        <location filename="../qml/Control/NewAlbumDialog.qml" line="25"/>
        <source>Unnamed</source>
        <translation>未命名相冊</translation>
    </message>
    <message>
        <location filename="../qml/Control/NewAlbumDialog.qml" line="56"/>
        <source>New Album</source>
        <translation>建立相冊</translation>
    </message>
    <message>
        <location filename="../qml/Control/NewAlbumDialog.qml" line="72"/>
        <source>Name:</source>
        <translation>檔案名：</translation>
    </message>
    <message>
        <location filename="../qml/Control/NewAlbumDialog.qml" line="103"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../qml/Control/NewAlbumDialog.qml" line="120"/>
        <source>Confirm</source>
        <translation>確定</translation>
    </message>
</context>
<context>
    <name>NoPermissionImageDelegate</name>
    <message>
        <location filename="../qml/PreviewImageViewer/ImageDelegate/NoPermissionImageDelegate.qml" line="22"/>
        <source>You have no permission to view the image</source>
        <translation>您沒有權限檢視此圖片</translation>
    </message>
</context>
<context>
    <name>NoPictureView</name>
    <message>
        <location filename="../qml/ThumbnailImageView/NoPictureView.qml" line="60"/>
        <source>Import Photos and Videos</source>
        <translation>匯入照片和影片</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/NoPictureView.qml" line="69"/>
        <source>No photos or videos found</source>
        <translation>未發現照片或影片檔案</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/NoPictureView.qml" line="69"/>
        <source>Or drag them here</source>
        <translation>您也可以拖曳照片和影片到此</translation>
    </message>
</context>
<context>
    <name>NoResultWidget</name>
    <message>
        <location filename="../src/widgets/widgtes/noresultwidget.cpp" line="39"/>
        <source>No results</source>
        <translation>無結果</translation>
    </message>
</context>
<context>
    <name>NonexistImageDelegate</name>
    <message>
        <location filename="../qml/PreviewImageViewer/ImageDelegate/NonexistImageDelegate.qml" line="42"/>
        <source>Image file not found</source>
        <translation>未發現圖片文件</translation>
    </message>
</context>
<context>
    <name>OpenImageWidget</name>
    <message>
        <location filename="../qml/PreviewImageViewer/OpenImageWidget.qml" line="35"/>
        <source>Open Image</source>
        <translation>打開圖片</translation>
    </message>
</context>
<context>
    <name>PathManager</name>
    <message>
        <location filename="../src/albumControl.cpp" line="1098"/>
        <source>System Disk</source>
        <translation>系統盤</translation>
    </message>
</context>
<context>
    <name>PropertyActionItemDelegate</name>
    <message>
        <location filename="../qml/PreviewImageViewer/PropertyActionItemDelegate.qml" line="67"/>
        <location filename="../qml/PreviewImageViewer/InformationDialog/PropertyActionItemDelegate.qml" line="95"/>
        <source>The file already exists, please use another name</source>
        <translation>該文件已存在，請使用其他名稱</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/albumControl.cpp" line="635"/>
        <location filename="../src/albumControl.cpp" line="684"/>
        <source>%1/%2/%3 %4:%5</source>
        <translation>%1/%2/%3 %4:%5</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="666"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="672"/>
        <source>%1/%2</source>
        <translation>%1/%2</translation>
    </message>
    <message>
        <location filename="../src/widgets/timelineview/timelineview.cpp" line="289"/>
        <location filename="../src/widgets/importtimelineview/importtimelineview.cpp" line="325"/>
        <location filename="../src/albumControl.cpp" line="678"/>
        <source>%1/%2/%3</source>
        <translation>%1年%2月%3日</translation>
    </message>
    <message>
        <location filename="../src/widgets/timelineview/timelineview.cpp" line="361"/>
        <location filename="../src/widgets/timelineview/timelineview.cpp" line="368"/>
        <location filename="../src/widgets/importtimelineview/importtimelineview.cpp" line="397"/>
        <location filename="../src/widgets/importtimelineview/importtimelineview.cpp" line="404"/>
        <source>All</source>
        <translation>所有項目</translation>
    </message>
    <message>
        <location filename="../src/widgets/timelineview/timelineview.cpp" line="376"/>
        <location filename="../src/widgets/importtimelineview/importtimelineview.cpp" line="412"/>
        <source>Photos</source>
        <translation>照片</translation>
    </message>
    <message>
        <location filename="../src/widgets/timelineview/timelineview.cpp" line="383"/>
        <location filename="../src/widgets/importtimelineview/importtimelineview.cpp" line="419"/>
        <source>Videos</source>
        <translation>影片</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="1355"/>
        <source>Trash</source>
        <translation>最近刪除</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="65"/>
        <source>Album</source>
        <translation>相冊</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="68"/>
        <source>Main</source>
        <comment>Album is a fashion manager for viewing and organizing photos and videos.</comment>
        <translation>相簿是一款可多種方式瀏覽、整理照片和影片的管理工具。</translation>
    </message>
    <message>
        <location filename="../src/unionimage/unionimage_global.h" line="269"/>
        <source>day</source>
        <translation>天</translation>
    </message>
    <message>
        <location filename="../src/widgets/importtimelineview/importtimelineview.cpp" line="322"/>
        <source>Imported on</source>
        <translation>匯入於</translation>
    </message>
    <message>
        <location filename="../src/widgets/importtimelineview/importtimelineview.cpp" line="322"/>
        <source> %1-%2-%3 %4</source>
        <translation>%1年%2月%3日 %4</translation>
    </message>
    <message>
        <location filename="../src/widgets/importtimelineview/importtimelineview.cpp" line="325"/>
        <source>Imported on </source>
        <translation>匯入於 </translation>
    </message>
    <message>
        <source>%1-%2-%3 %4</source>
        <translation type="vanished">%1年%2月%3日 %4</translation>
    </message>
    <message>
        <location filename="../src/widgets/timelineview/timelineview.cpp" line="236"/>
        <location filename="../src/widgets/thumbnail/timelinedatewidget.cpp" line="48"/>
        <location filename="../src/widgets/thumbnail/timelinedatewidget.cpp" line="164"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="1360"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="2106"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="2115"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="2121"/>
        <location filename="../src/widgets/importtimelineview/importtimelineview.cpp" line="440"/>
        <source>Select</source>
        <translation>選擇</translation>
    </message>
    <message>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="1360"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="2115"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="2121"/>
        <source>Unselect</source>
        <translation>取消選擇</translation>
    </message>
</context>
<context>
    <name>ReName</name>
    <message>
        <location filename="../qml/PreviewImageViewer/ReName.qml" line="66"/>
        <source>Input a new name</source>
        <translation>請輸入圖片名稱</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ReName.qml" line="81"/>
        <source>The file already exists, please use another name</source>
        <translation>該文件已存在，請使用其他名稱</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ReName.qml" line="137"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ReName.qml" line="119"/>
        <source>Confirm</source>
        <translation>確定</translation>
    </message>
</context>
<context>
    <name>RecentlyDeletedView</name>
    <message>
        <location filename="../qml/ThumbnailImageView/RecentlyDeletedView/RecentlyDeletedView.qml" line="52"/>
        <source>1 photo</source>
        <translation>共1張照片</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/RecentlyDeletedView/RecentlyDeletedView.qml" line="54"/>
        <source>%1 photos</source>
        <translation>共%1張照片</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/RecentlyDeletedView/RecentlyDeletedView.qml" line="62"/>
        <source>1 video</source>
        <translation>共1個影片</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/RecentlyDeletedView/RecentlyDeletedView.qml" line="64"/>
        <source>%1 videos</source>
        <translation>共%1個影片</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/RecentlyDeletedView/RecentlyDeletedView.qml" line="123"/>
        <source>Trash</source>
        <translation>最近刪除</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/RecentlyDeletedView/RecentlyDeletedView.qml" line="144"/>
        <source>The files will be permanently deleted after the days shown on them</source>
        <translation>文件在刪除前會顯示剩餘天數，之後將永久刪除</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/RecentlyDeletedView/RecentlyDeletedView.qml" line="159"/>
        <source>Delete All</source>
        <translation>全部刪除</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/RecentlyDeletedView/RecentlyDeletedView.qml" line="199"/>
        <source>Delete Selected (%1)</source>
        <translation>刪除%1項</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/RecentlyDeletedView/RecentlyDeletedView.qml" line="219"/>
        <source>Restore Selected (%1)</source>
        <translation>復原%1項</translation>
    </message>
</context>
<context>
    <name>RemoveAlbumDialog</name>
    <message>
        <location filename="../qml/Control/RemoveAlbumDialog.qml" line="42"/>
        <source>Are you sure you want to delete this album?</source>
        <translation>您確定要刪除此相冊嗎？</translation>
    </message>
    <message>
        <location filename="../qml/Control/RemoveAlbumDialog.qml" line="55"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../qml/Control/RemoveAlbumDialog.qml" line="72"/>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
</context>
<context>
    <name>RemoveDialog</name>
    <message>
        <location filename="../qml/PreviewImageViewer/Dialog/RemoveDialog.qml" line="66"/>
        <source>Cannot move &quot;%1&quot; to the trash. Do you want to permanently delete it?</source>
        <translation>無法將「%1」放到回收站，您要徹底刪除嗎？</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/Dialog/RemoveDialog.qml" line="84"/>
        <source>This action cannot be undone</source>
        <translation>此操作不可以恢復</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/Dialog/RemoveDialog.qml" line="96"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/Dialog/RemoveDialog.qml" line="106"/>
        <source>Confirm</source>
        <translation>確定</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <location filename="../qml/ThumbnailImageView/SearchView.qml" line="51"/>
        <source>1 photo found</source>
        <translation>共找到1張照片</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/SearchView.qml" line="53"/>
        <source>%1 photos found</source>
        <translation>共找到%1張照片</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/SearchView.qml" line="57"/>
        <source>1 video found</source>
        <translation>共找到1個影片</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/SearchView.qml" line="59"/>
        <source>%1 videos found</source>
        <translation>共找到%1個影片</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/SearchView.qml" line="64"/>
        <source>%1 items found</source>
        <translation>共找到%1項</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/SearchView.qml" line="99"/>
        <source>Search results</source>
        <translation>搜尋結果</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/SearchView.qml" line="112"/>
        <source>Slide Show</source>
        <translation>幻燈片放映</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/SearchView.qml" line="189"/>
        <source>No search results</source>
        <translation>無搜尋結果</translation>
    </message>
</context>
<context>
    <name>Sidebar</name>
    <message>
        <location filename="../qml/SideBar/Sidebar.qml" line="127"/>
        <location filename="../qml/SideBar/Sidebar.qml" line="151"/>
        <source>Album “%1” removed</source>
        <translation>已成功刪除“%1”相冊</translation>
    </message>
    <message>
        <location filename="../qml/SideBar/Sidebar.qml" line="205"/>
        <source>Gallery</source>
        <translation>照片庫</translation>
    </message>
    <message>
        <location filename="../qml/SideBar/Sidebar.qml" line="208"/>
        <source>Collection</source>
        <translation>合集</translation>
    </message>
    <message>
        <location filename="../qml/SideBar/Sidebar.qml" line="209"/>
        <source>Import</source>
        <translation>已匯入</translation>
    </message>
    <message>
        <location filename="../qml/SideBar/Sidebar.qml" line="210"/>
        <source>Favorites</source>
        <translation>我的收藏</translation>
    </message>
    <message>
        <location filename="../qml/SideBar/Sidebar.qml" line="211"/>
        <source>Trash</source>
        <translation>最近刪除</translation>
    </message>
    <message>
        <location filename="../qml/SideBar/Sidebar.qml" line="234"/>
        <source>Device</source>
        <translation>裝置</translation>
    </message>
    <message>
        <location filename="../qml/SideBar/Sidebar.qml" line="292"/>
        <source>Albums</source>
        <translation>相冊</translation>
    </message>
    <message>
        <location filename="../qml/SideBar/Sidebar.qml" line="313"/>
        <source>Add an album</source>
        <translation>建立相冊</translation>
    </message>
    <message>
        <location filename="../qml/SideBar/Sidebar.qml" line="340"/>
        <source>Screen Capture</source>
        <translation>截圖錄屏</translation>
    </message>
    <message>
        <location filename="../qml/SideBar/Sidebar.qml" line="344"/>
        <source>Camera</source>
        <translation>相機</translation>
    </message>
    <message>
        <location filename="../qml/SideBar/Sidebar.qml" line="348"/>
        <source>Draw</source>
        <translation>畫板</translation>
    </message>
    <message>
        <location filename="../qml/SideBar/Sidebar.qml" line="455"/>
        <location filename="../qml/SideBar/Sidebar.qml" line="480"/>
        <location filename="../qml/SideBar/Sidebar.qml" line="534"/>
        <source>Slide show</source>
        <translation>幻燈片放映</translation>
    </message>
    <message>
        <location filename="../qml/SideBar/Sidebar.qml" line="466"/>
        <location filename="../qml/SideBar/Sidebar.qml" line="492"/>
        <location filename="../qml/SideBar/Sidebar.qml" line="567"/>
        <source>Export</source>
        <translation>匯出</translation>
    </message>
    <message>
        <location filename="../qml/SideBar/Sidebar.qml" line="500"/>
        <location filename="../qml/SideBar/Sidebar.qml" line="576"/>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <location filename="../qml/SideBar/Sidebar.qml" line="543"/>
        <source>New album</source>
        <translation>建立相冊</translation>
    </message>
    <message>
        <location filename="../qml/SideBar/Sidebar.qml" line="555"/>
        <source>Rename</source>
        <translation>重新命名</translation>
    </message>
</context>
<context>
    <name>SliderShow</name>
    <message>
        <location filename="../qml/PreviewImageViewer/SliderShow.qml" line="164"/>
        <source>Previous</source>
        <translation>上一張</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/SliderShow.qml" line="181"/>
        <location filename="../qml/PreviewImageViewer/SliderShow.qml" line="232"/>
        <source>Pause</source>
        <translation>暫停</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/SliderShow.qml" line="181"/>
        <location filename="../qml/PreviewImageViewer/SliderShow.qml" line="232"/>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/SliderShow.qml" line="197"/>
        <source>Next</source>
        <translation>下一張</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/SliderShow.qml" line="212"/>
        <location filename="../qml/PreviewImageViewer/SliderShow.qml" line="253"/>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
</context>
<context>
    <name>ThumbnailListDelegate</name>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListDelegate.qml" line="441"/>
        <source>days</source>
        <translation>天</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListDelegate.qml" line="441"/>
        <source>day</source>
        <translation>天</translation>
    </message>
</context>
<context>
    <name>ThumbnailListView</name>
    <message>
        <location filename="../qml/PreviewImageViewer/ThumbnailListView.qml" line="610"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="762"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="764"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="804"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="807"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="809"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="819"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="948"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="965"/>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ThumbnailListView.qml" line="171"/>
        <source>Back to Album</source>
        <translation>返回相冊</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ThumbnailListView.qml" line="203"/>
        <source>Previous</source>
        <translation>上一張</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ThumbnailListView.qml" line="228"/>
        <source>Next</source>
        <translation>下一張</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ThumbnailListView.qml" line="264"/>
        <source>Original size</source>
        <translation>原始大小</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ThumbnailListView.qml" line="283"/>
        <source>Fit to window</source>
        <translation>適應視窗</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ThumbnailListView.qml" line="301"/>
        <source>Rotate</source>
        <translation>旋轉</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ThumbnailListView.qml" line="335"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="772"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="776"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="828"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="836"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="838"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="969"/>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ThumbnailListView.qml" line="335"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="773"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="775"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="830"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="835"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="839"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="970"/>
        <source>Unfavorite</source>
        <translation>取消收藏</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ThumbnailListView.qml" line="591"/>
        <source>Extract text</source>
        <translation>識別文字</translation>
    </message>
    <message>
        <location filename="../src/widgets/thumbnail/thumbnaildelegate.cpp" line="207"/>
        <source>days</source>
        <translation>天</translation>
    </message>
    <message>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="723"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="726"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="730"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="782"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="868"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="876"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="882"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="950"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="979"/>
        <source>Photo info</source>
        <translation>照片訊息</translation>
    </message>
    <message>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="724"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="727"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="731"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="783"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="869"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="872"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="883"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="951"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="980"/>
        <source>Video info</source>
        <translation>影片訊息</translation>
    </message>
    <message>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="746"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="798"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="931"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="957"/>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="747"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="799"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="870"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="877"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="958"/>
        <source>Fullscreen</source>
        <translation>全螢幕</translation>
    </message>
    <message>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="748"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="874"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="888"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="897"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="960"/>
        <source>Slide show</source>
        <translation>幻燈片放映</translation>
    </message>
    <message>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="749"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="754"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="817"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="875"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="889"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="962"/>
        <source>Export</source>
        <translation>匯出</translation>
    </message>
    <message>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="759"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="963"/>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="767"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="844"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="966"/>
        <source>Remove from album</source>
        <translation>從相冊中移除</translation>
    </message>
    <message>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="769"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="873"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="887"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="959"/>
        <source>Print</source>
        <translation>列印</translation>
    </message>
    <message>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="779"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="859"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="862"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="903"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="906"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="973"/>
        <source>Rotate clockwise</source>
        <translation>順時針旋轉</translation>
    </message>
    <message>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="780"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="860"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="863"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="904"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="907"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="974"/>
        <source>Rotate counterclockwise</source>
        <translation>逆時針旋轉</translation>
    </message>
    <message>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="781"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="881"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="978"/>
        <source>Display in file manager</source>
        <translation>在檔案管理器中顯示</translation>
    </message>
    <message>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="784"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="790"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="791"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="878"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="914"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="916"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="919"/>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="977"/>
        <source>Set as wallpaper</source>
        <translation>設為桌布</translation>
    </message>
    <message>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="949"/>
        <source>Restore</source>
        <translation>復原</translation>
    </message>
    <message>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="986"/>
        <source>Add to album</source>
        <translation>添加到相冊</translation>
    </message>
    <message>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="990"/>
        <source>New album</source>
        <translation>建立相冊</translation>
    </message>
</context>
<context>
    <name>ThumbnailListViewAlbum</name>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="796"/>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="805"/>
        <source>Fullscreen</source>
        <translation>全螢幕</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="822"/>
        <source>Print</source>
        <translation>列印</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="841"/>
        <source>Slide show</source>
        <translation>幻燈片放映</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="867"/>
        <source>Add to album</source>
        <translation>添加到相冊</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="870"/>
        <source>New album</source>
        <translation>建立相冊</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="902"/>
        <source>Successfully added to “%1”</source>
        <translation>成功添加到“%1”</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="911"/>
        <source>Export</source>
        <translation>匯出</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="930"/>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="939"/>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="949"/>
        <source>Remove from album</source>
        <translation>從相冊中移除</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="964"/>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="974"/>
        <source>Unfavorite</source>
        <translation>取消收藏</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="988"/>
        <source>Rotate clockwise</source>
        <translation>順時針旋轉</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="997"/>
        <source>Rotate counterclockwise</source>
        <translation>逆時針旋轉</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="1006"/>
        <source>Set as wallpaper</source>
        <translation>設為桌布</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="1025"/>
        <source>Display in file manager</source>
        <translation>在檔案管理器中顯示</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="1044"/>
        <source>Restore</source>
        <translation>復原</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="1053"/>
        <source>Photo info</source>
        <translation>照片訊息</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="1072"/>
        <source>Video info</source>
        <translation>影片訊息</translation>
    </message>
</context>
<context>
    <name>TimeLineView</name>
    <message>
        <location filename="../src/widgets/timelineview/timelineview.cpp" line="304"/>
        <source>1 photo</source>
        <translation>共1張照片</translation>
    </message>
    <message>
        <location filename="../src/widgets/timelineview/timelineview.cpp" line="306"/>
        <source>1 video</source>
        <translation>共1個影片</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/widgets/timelineview/timelineview.cpp" line="308"/>
        <source>%n photos</source>
        <translation>
            <numerusform>共%n張照片</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/widgets/timelineview/timelineview.cpp" line="310"/>
        <source>%n videos</source>
        <translation>
            <numerusform>共%n個影片</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/widgets/timelineview/timelineview.cpp" line="312"/>
        <source>%n items</source>
        <translation>
            <numerusform>共%n項</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ToolBarThumbnailListView</name>
    <message>
        <location filename="../qml/PreviewImageViewer/ToolBarThumbnailListView.qml" line="121"/>
        <source>Back to Album</source>
        <translation>返回相冊</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ToolBarThumbnailListView.qml" line="162"/>
        <source>Previous</source>
        <translation>上一張</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ToolBarThumbnailListView.qml" line="189"/>
        <source>Next</source>
        <translation>下一張</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ToolBarThumbnailListView.qml" line="210"/>
        <source>Original size</source>
        <translation>原始大小</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ToolBarThumbnailListView.qml" line="231"/>
        <source>Fit to window</source>
        <translation>適應視窗</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ToolBarThumbnailListView.qml" line="257"/>
        <source>Rotate</source>
        <translation>旋轉</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ToolBarThumbnailListView.qml" line="290"/>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ToolBarThumbnailListView.qml" line="290"/>
        <source>Unfavorite</source>
        <translation>取消收藏</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ToolBarThumbnailListView.qml" line="431"/>
        <source>Extract text</source>
        <translation>識別文字</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ToolBarThumbnailListView.qml" line="458"/>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
</context>
<context>
    <name>VideoInfoDialog</name>
    <message>
        <location filename="../qml/Control/VideoInfoDialog.qml" line="73"/>
        <source>Basic info</source>
        <translation>基本訊息</translation>
    </message>
    <message>
        <location filename="../qml/Control/VideoInfoDialog.qml" line="78"/>
        <source>File name</source>
        <translation>檔案名</translation>
    </message>
    <message>
        <location filename="../qml/Control/VideoInfoDialog.qml" line="88"/>
        <source>Date captured</source>
        <translation>拍攝日期</translation>
    </message>
    <message>
        <location filename="../qml/Control/VideoInfoDialog.qml" line="95"/>
        <source>Size</source>
        <translation>大小</translation>
    </message>
    <message>
        <location filename="../qml/Control/VideoInfoDialog.qml" line="100"/>
        <source>Duration</source>
        <translation>時長</translation>
    </message>
    <message>
        <location filename="../qml/Control/VideoInfoDialog.qml" line="105"/>
        <source>Type</source>
        <translation>文件類型</translation>
    </message>
    <message>
        <location filename="../qml/Control/VideoInfoDialog.qml" line="115"/>
        <source>Path</source>
        <translation>文件路徑</translation>
    </message>
    <message>
        <location filename="../qml/Control/VideoInfoDialog.qml" line="122"/>
        <source>Codec info</source>
        <translation>編碼訊息</translation>
    </message>
    <message>
        <location filename="../qml/Control/VideoInfoDialog.qml" line="130"/>
        <location filename="../qml/Control/VideoInfoDialog.qml" line="170"/>
        <source>Video CodecID</source>
        <translation>影片軌訊息</translation>
    </message>
    <message>
        <location filename="../qml/Control/VideoInfoDialog.qml" line="136"/>
        <source>Video CodeRate</source>
        <translation>影片碼率</translation>
    </message>
    <message>
        <location filename="../qml/Control/VideoInfoDialog.qml" line="142"/>
        <source>FPS</source>
        <translation>影片幀率</translation>
    </message>
    <message>
        <location filename="../qml/Control/VideoInfoDialog.qml" line="153"/>
        <source>Proportion</source>
        <translation>顯示比例</translation>
    </message>
    <message>
        <location filename="../qml/Control/VideoInfoDialog.qml" line="160"/>
        <source>Resolution</source>
        <translation>解析度</translation>
    </message>
    <message>
        <location filename="../qml/Control/VideoInfoDialog.qml" line="178"/>
        <source>Audio CodecID</source>
        <translation>編碼樣式</translation>
    </message>
    <message>
        <location filename="../qml/Control/VideoInfoDialog.qml" line="184"/>
        <source>Audio CodeRate</source>
        <translation>編碼碼率</translation>
    </message>
    <message>
        <location filename="../qml/Control/VideoInfoDialog.qml" line="190"/>
        <source>Audio digit</source>
        <translation>音訊位數</translation>
    </message>
    <message>
        <location filename="../qml/Control/VideoInfoDialog.qml" line="201"/>
        <source>Channels</source>
        <translation>聲道數</translation>
    </message>
    <message>
        <location filename="../qml/Control/VideoInfoDialog.qml" line="208"/>
        <source>Sampling</source>
        <translation>採樣數</translation>
    </message>
</context>
<context>
    <name>ViewRightMenu</name>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewRightMenu.qml" line="40"/>
        <source>Fullscreen</source>
        <translation>全螢幕</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewRightMenu.qml" line="40"/>
        <source>Exit fullscreen</source>
        <translation>退出全螢幕</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewRightMenu.qml" line="60"/>
        <source>Print</source>
        <translation>列印</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewRightMenu.qml" line="81"/>
        <source>Extract text</source>
        <translation>識別文字</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewRightMenu.qml" line="103"/>
        <source>Slide show</source>
        <translation>幻燈片放映</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewRightMenu.qml" line="128"/>
        <source>Export</source>
        <translation>匯出</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewRightMenu.qml" line="144"/>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewRightMenu.qml" line="168"/>
        <source>Rename</source>
        <translation>重新命名</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewRightMenu.qml" line="189"/>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewRightMenu.qml" line="218"/>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewRightMenu.qml" line="228"/>
        <source>Unfavorite</source>
        <translation>取消收藏</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewRightMenu.qml" line="245"/>
        <source>Rotate clockwise</source>
        <translation>順時針旋轉</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewRightMenu.qml" line="267"/>
        <source>Rotate counterclockwise</source>
        <translation>逆時針旋轉</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewRightMenu.qml" line="297"/>
        <source>Show navigation window</source>
        <translation>顯示導航視窗</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewRightMenu.qml" line="297"/>
        <source>Hide navigation window</source>
        <translation>隱藏導航視窗</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewRightMenu.qml" line="309"/>
        <source>Set as wallpaper</source>
        <translation>設為桌布</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewRightMenu.qml" line="331"/>
        <source>Display in file manager</source>
        <translation>在檔案管理器中顯示</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewRightMenu.qml" line="350"/>
        <source>Image info</source>
        <translation>圖片訊息</translation>
    </message>
</context>
<context>
    <name>ViewTopTitle</name>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewTopTitle.qml" line="162"/>
        <source>Open image</source>
        <translation>打開圖片</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewTopTitle.qml" line="184"/>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>看圖是一款外觀時尚，效能流暢的圖片檢視工具。</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewTopTitle.qml" line="185"/>
        <source>Album is a stylish management tool for viewing and organizing photos and videos.</source>
        <translation>相冊是一款可多種方式瀏覽、整理照片和影片的管理工具。</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewTopTitle.qml" line="188"/>
        <source>Image Viewer</source>
        <translation>看圖</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewTopTitle.qml" line="189"/>
        <source>Album</source>
        <translation>相冊</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewTopTitle.qml" line="193"/>
        <source>%1 is released under %2.</source>
        <translation>%1遵循%2協議釋出</translation>
    </message>
</context>
<context>
    <name>YearCollection</name>
    <message>
        <location filename="../qml/ThumbnailImageView/CollecttionView/YearCollection.qml" line="126"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/CollecttionView/YearCollection.qml" line="139"/>
        <source>%1 items</source>
        <translation>共%1項</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/CollecttionView/YearCollection.qml" line="139"/>
        <source>1 item</source>
        <translation>共1項</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../qml/main.qml" line="130"/>
        <source>All photos and videos</source>
        <translation>所有照片和影片</translation>
    </message>
</context>
</TS>
